# Enums

Enumeration types for haolib.

## Overview

The enums module provides enumeration types used throughout haolib.

## Components

- **Base**: Base enumeration classes
- **Filter**: Filter enumeration types
